==> tine20-allinone_2019.12.5.tar.bz2: Filemanager/js/Filemanager-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ru\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Upload Failed"
: "Сбой загрузки"

, "Putting files in this folder is not allowed!"
: "Помещение файлов в этой папке не допускается!"

, "Filemanager"
: "Менеджер файлов"

, "Save locally"
: "Сохранить локально"

, "Tags"
: "Теги"

, "Name"
: "Имя"

, "Size"
: "Размер"

, "Contenttype"
: "Тип содержимого"

, "Folder, Folders"
: [
  ""
 ,""
 ,"Папка"
 ,"Папка"

]
, "Creation Time"
: "Время создания"

, "Created By"
: "Создана"

, "Last Modified Time"
: "Время последнего изменения"

, "Last Modified By"
: "Последнее изменение:"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Загрузить"

, "Open Data Safe"
: ""

, "Folder Up"
: "Вверх на уровень"

, "Close Data Safe"
: ""

, "Node Download Links"
: ""

, "Url"
: "URL"

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Service Unavailable"
: "Сервис не доступен"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Менеджер файлов не настроен правильно. Пожалуйста, обратитесь к {0} ЧАВО администратора Tine 2.0 {1} для рекомендаций по настройке  или к администратору."

, "Files already exists"
: "Файлы уже существуют"

, "Do you want to replace the following file(s)?"
: "Вы хотите заменить следующий(е) файл(ы)?"

, "Failure on create folder"
: "Сбой при создании папки"

, "Item with this name already exists!"
: "Элемент с таким именем уже существует!"

, "Revision"
: "Ревизия"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "path"
: "путь"

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Reload"
: ""

, "Create Folder"
: "Создать папку"

, "New Folder"
: "Новая папка"

, "Please enter the name of the new folder:"
: "Введите имя новой папки:"

, "No {0} added"
: "{0} не добавлен"

, "You have to supply a {0} name!"
: "Вы должны указать имя {0}!"

, "Edit Properties"
: "Изменить свойства"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Введите новое имя для {0}:"

, "Not renamed {0}"
: "Не переименовано {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Удалить"

, "Do you really want to delete the following files?"
: "Вы действительно хотите удалить следующие файлы?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Publish"
: "Опубликовать"

, "Public download links can be password protected. If left blank anyone who knows the link can download the selected files."
: ""

, "Folder has been published successfully"
: "Папка успешно опубликована"

, "File has been published successfully"
: "Файл успешно опубликован"

, "File, Files"
: [
  "Файл"
 ,"Файла"
 ,"Файлов"
 ,"Файлов"

]
, "The grant to download files"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Копирование данных... {0}"

, "Moving data .. {0}"
: "Перемещение данных... {0}"

, "Please wait"
: "Пожалуйста, подождите"

, "Quick Search"
: "Быстрый поиск"

, "Type"
: "Тип"

, "Description"
: "Описание"

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""
 ,""
 ,""

]
, "Grants"
: ""

, "This folder has own grants"
: ""

, "Grants of a folder also apply recursively for all of its sub folders as long they don't have own grants itself."
: ""

, "This folder is part of the data safe"
: ""

, "If data safe protection is enabled, this folder and all it's contents is only shown if the data safe is opened."
: ""

, "Sorry, Tine 2.0 would like to show you the contents of the file displayed."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We are happy make you a non-binding offer."
: ""

, "No preview available."
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""
 ,""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Remove record"
: "Удалить запись"

, "Search for groups ..."
: ""

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: "Редактировать папку"

, "edit file"
: "редактировать файл"

, "Public Links"
: "Внешняя ссылка"

, "Not yet indexed"
: ""

, "Modified By"
: "Изменено"

, "Last Modified"
: "Последнее изменение"

, "Enter description"
: "Введите описание"

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Create Public Link"
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Usage"
: ""

, "The Quota applies recursively for files and subfolders. Please note, the Effective Quota differs wehn a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "Row double click default"
: ""

, "Defines which action should be executed on double click by default?"
: ""

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Public Download URL"
: ""

, "Serve anonymous downloads from a different URL. Make sure to setup proper rewrite rules."
: ""

, "manage shared folders"
: "управление общими папками"

, "Create new shared folders"
: "Создание новых  общих папок"

, "Manage anonymous download links"
: ""

, "Allow to see, add and delete download links of files and folders"
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path the source has. No action has been performed."
: ""

, "My folders"
: "Мои папки"

, "Shared folders"
: "Общие папки"

, "Other users folders"
: "Папки других пользователей"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Folder"
: ""

, "File"
: "Файл"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Filemanager/js/Filemanager-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Name"
: "Имя"

, "Size"
: "Размер"

, "Last Modified"
: "Последнее изменение"

, "Description"
: "Описание"

, "Folder, Folders"
: [
  ""
 ,""
 ,"Папка"
 ,"Папка"

]
, "File, Files"
: [
  "Файл"
 ,"Файла"
 ,"Файлов"
 ,"Файлов"

]
, "Default behavior when double-clicking on a Row"
: ""

, "Defines which action should be executed by default when double-clicked."
: ""

, "Invalid Filename"
: ""

, "Content type"
: ""

, "path"
: "путь"

, "URL"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Create Public Link"
: ""

, "Remove record"
: "Удалить запись"

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "Created By"
: "Создана"

, "Creation Time"
: "Время создания"

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Last Modified Time"
: "Время последнего изменения"

, "Last Modified By"
: "Последнее изменение:"

, "Revision"
: "Ревизия"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "Upload Failed"
: "Сбой загрузки"

, "It is not permitted to store files in this folder!"
: ""

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Tags"
: "Теги"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Загрузить"

, "Open Data Safe"
: ""

, "Folder Up"
: "Вверх на уровень"

, "Close Data Safe"
: ""

, "Filemanager"
: "Менеджер файлов"

, "Save locally"
: "Сохранить локально"

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: "Редактировать папку"

, "edit file"
: "редактировать файл"

, "Public Links"
: "Внешняя ссылка"

, "Type"
: "Тип"

, "Not yet indexed"
: ""

, "Modified By"
: "Изменено"

, "Enter description"
: "Введите описание"

, "Service Unavailable"
: "Сервис не доступен"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Менеджер файлов не настроен правильно. Пожалуйста, обратитесь к {0} ЧАВО администратора Tine 2.0 {1} для рекомендаций по настройке  или к администратору."

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "Вы хотите заменить следующий(е) файл(ы)?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "Элемент с таким именем уже существует!"

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "The grant to download files"
: ""

, "Publish"
: "Опубликовать"

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Копирование данных... {0}"

, "Moving data .. {0}"
: "Перемещение данных... {0}"

, "Please wait"
: "Пожалуйста, подождите"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Quick Search"
: "Быстрый поиск"

, "Content Type"
: ""

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""
 ,""
 ,""

]
, "Node Download Links"
: ""

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""
 ,""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Search for groups ..."
: ""

, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: ""

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Reload"
: ""

, "Create Folder"
: "Создать папку"

, "New Folder"
: "Новая папка"

, "Please enter the name of the new folder:"
: "Введите имя новой папки:"

, "No {0} added"
: "{0} не добавлен"

, "You have to supply a {0} name!"
: "Вы должны указать имя {0}!"

, "Edit Properties"
: "Изменить свойства"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Введите новое имя для {0}:"

, "Not renamed {0}"
: "Не переименовано {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Удалить"

, "Do you really want to delete the following files?"
: "Вы действительно хотите удалить следующие файлы?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Folder has been published successfully"
: "Папка успешно опубликована"

, "File has been published successfully"
: "Файл успешно опубликован"

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Мои папки"

, "Shared folders"
: "Общие папки"

, "Other users folders"
: "Папки других пользователей"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path as the source. No action has been performed."
: ""

, "manage shared folders"
: "управление общими папками"

, "Create new shared folders"
: "Создание новых  общих папок"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""






, "Folder"
: ""

, "File"
: "Файл"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
